class Document:
    def __init__(self, width, height, nodes):
        self.width = width
        self.height = height
        self.nodes = nodes
